fx:Class markup extension

The fx:Class markup extension resolves a name to a class literal.

Properties

Property Description
name A string that specifies the class name. This is the default property.

Usage

<!-- Element notation -->
<object>
    <property>
        <fx:Class name="MyClass"/>
    </property>
<object>

<!-- Attribute notation -->
<object property="{fx:Class name=MyClass}"/>

<!-- Attribute notation with omitted "name" -->
<object property="{fx:Class MyClass}"/>

This site uses Just the Docs, a documentation theme for Jekyll.