fx:classModifier attribute
The fx:classModifier attribute specifies the access modifier of the generated class. When omitted, the generated class has a public access modifier.
The fx:classModifier attribute can only be set on the root element.
Values
| Value | Java class modifier |
|---|---|
| (not specified) | public |
| protected | protected |
| package | package-private (no modifier) |
Usage
<BorderPane xmlns="http://javafx.com/javafx" xmlns:fx="http://jfxcore.org/fxml/2.0"
fx:classModifier="protected">
</BorderPane>