fx:content markup extension, $..x
The fx:content markup extension assigns the content of a collection. It can be set on any List, Set, or Map property, and is equivalent to invoking the List.addAll(Collection), Set.addAll(Collection), or Map.putAll(Map) API in Java code.
Its prefix notation is $..x, where x is the binding path.
Properties
| Property | Description |
|---|---|
path | A string that specifies the binding path. This is the default property. |
Usage
<!-- Element notation -->
<object>
<property>
<fx:content path="myPath"/>
</property>
<object>
<!-- Attribute notation -->
<object property="{fx:content path=myPath}"/>
<!-- Attribute notation with omitted "path" -->
<object property="{fx:content myPath}"/>
<!-- Prefix notation -->
<object property="$..myPath"/>