fx:once markup extension, $x
The fx:once markup extension resolves a value and assigns it to a property. Even if the source is an ObservableValue, no binding is established and the value is not updated after the initial assignment.
Its prefix notation is $x, where x is the binding path.
Properties
| Property | Description |
|---|---|
path | A string that specifies the binding path. This is the default property. |
Usage
<!-- Element notation -->
<object>
<property>
<fx:once path="myPath"/>
</property>
<object>
<!-- Attribute notation -->
<object property="{fx:once path=myPath}"/>
<!-- Attribute notation with omitted "path" -->
<object property="{fx:once myPath}"/>
<!-- Prefix notation -->
<object property="$myPath"/>