fx:Push markup extension, >{x}

The fx:Push markup extension establishes a reverse binding that pushes values from the binding target to the source. It is only valid in property-consumer position and cannot be used where a value or ObservableValue is expected.

A leading .. in the source path selects the content of the target and source collection. In that form, fx:Push establishes a reverse content binding between the source and target collections.

Its prefix notation is >{x}, where x is the source path.

Properties

Property Description
source A string that specifies the source path. This is the default property.

Usage

<!-- Element notation -->
<object>
    <property>
        <fx:Push source="mySourcePath"/>
    </property>
</object>

<!-- Attribute notation -->
<object property="{fx:Push source=mySourcePath}"/>

<!-- Attribute notation with omitted "source=" -->
<object property="{fx:Push mySourcePath}"/>

<!-- Prefix notation -->
<object property=">{mySourcePath}"/>

<!-- Reverse content binding -->
<object property=">{..mySourcePath}"/>

This site uses Just the Docs, a documentation theme for Jekyll.