fx:value directive

The fx:value directive initializes an element by invoking a static valueOf(...) method to create an instance of the element. The valueOf(...) method may be declared on the type itself or on one of its superclasses.

Usage

<Button xmlns="http://javafx.com/javafx" xmlns:fx="http://jfxcore.org/fxml/2.0">
    <textFill>
        <Color fx:value="red"/>
    </textFill>
</Button>

fx:value is evaluated once during object initialization.
Evaluation expressions are supported, but observable expressions are not.


This site uses Just the Docs, a documentation theme for Jekyll.