fx:className directive
The fx:className directive controls the name of the generated class. If fx:className is not specified, the name of the generated class defaults to the standalone .fxml file name or the annotated Java class name, plus the Base suffix. For example, the default generated class name for MyControl.fxml will be MyControlBase.
In .fxml files, fx:className can only be used when fx:subclass is also specified.
Usage
com/sample/MyControl.fxml
<BorderPane xmlns="http://javafx.com/javafx" xmlns:fx="http://jfxcore.org/fxml/2.0"
fx:subclass="com.sample.MyControl"
fx:className="MyCustomBaseClass">
<BorderPane/>
com/sample/MyControl.java
public class MyControl extends MyCustomBaseClass {
MyControl() {
initializeComponent();
}
}