fx:False markup extension

The fx:False markup extension specifies the boolean false value.

In many cases, using the fx:False markup extension is not necessary. In a boolean assignment context, the text "false" is automatically converted to a boolean value by coercion.

Usage

<!-- Using the fx:False markup extension -->
<Button visible="{fx:False}"/>

<!-- Using value coercion -->
<Button visible="false"/>

This site uses Just the Docs, a documentation theme for Jekyll.