fx:True markup extension

The fx:True markup extension specifies the boolean true value.

In many cases, using the fx:True markup extension is not necessary. In a boolean assignment context, the text "true" is automatically converted to a boolean value by coercion.

Usage

<!-- Using the fx:True markup extension -->
<Button visible="{fx:True}"/>

<!-- Using value coercion -->
<Button visible="true"/>

This site uses Just the Docs, a documentation theme for Jekyll.